@@ -11,7 +11,6 @@ from pyqt_svg_label import SvgLabel
 
 from pyqt_windows_buttons_widget import WindowsButtonsWidget
 from pyqt_mac_buttons_widget import MacButtonsWidget
-import absresgetter
 
 
 class CustomTitlebarWindow(FramelessWindow):
@@ -243,7 +242,7 @@ class CustomTitlebarWindow(FramelessWindow):
 
     def __getWindowIcon(self, icon_filename):
         if icon_filename:
-            icon_filename = absresgetter.getabsres(icon_filename)
+            pass
         else:
             icon_filename = self.__widget.windowIcon().name()
         return icon_filename
